Available on crate feature
bytecode only.Expand description
Bytecode opcodes for the bytecode tape.
Each opcode represents an elementary operation. The eval_forward and
reverse_partials functions evaluate / differentiate a single opcode.
Enums
- OpCode
- Elementary operation codes for the bytecode tape.
Constants
- UNUSED
- Sentinel used in
arg_indices[1]for unary ops (the second argument slot is unused).
Functions
- eval_
forward - Evaluate a single opcode in the forward direction.
- forced_
reverse_ partials - Compute reverse-mode partials with a forced branch choice for nonsmooth ops.
- has_
nontrivial_ subdifferential - Returns true if forced branch choices produce distinct partial derivatives.
- is_
nonsmooth - Returns true if this opcode is a nonsmooth operation.
- powi_
exp_ decode_ raw - Decode a
powiexponent directly from the rawu32inarg_indices[1]. - powi_
exp_ encode - Encode a
powiexponent as a value that can be stored inarg_indices[1]. - reverse_
partials - Compute reverse-mode partial derivatives for a single opcode.